##  Creating Transformation Templates
To create a transformation template, do the following:
  1. Navigate to Administration > Transformations.
  2. In the Predefined Transformation Types tab, you can:
     * Configure the Rollout Application template and save it as new by clicking Configure as new against it.
     * Create a custom transformation template from scratch by clicking either Create Template at the top or by clicking Configure as new against Custom Transformation template at the bottom.
![Configuring Rollout Application Transformation Template](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b441a7a44101496c0f50a12e9c16a_LowRes.png)
Creating a Custom Transformation Template
  3. In the resulting overlay, add a name, category, and description, then click Save. It leads you to the template configuration page.
  4. In the template configuration page, click Add template field or Add impact, to add a field for the fact sheet or to define impacts. For Custom Transformation templates, you will start from scratch by adding template fields first.
  5. Configure the template fields, define the impacts, and click Save. For more details on configuring template fields, see Configuring Template Fields.
  6. Click Activate and Close at the top right corner.


You can find the newly added transformation template in the Configured Transformation Types tab of the configuration. From there, you can revisit and make any further modifications as needed.
These newly created custom templates will then be available for selection under the selected fact sheet type category in initiative fact sheets while creating transformations.
![Custom Transformation Template Available for Selection in the Initiative Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275572a37a441014a5bbbd1c091990d1_LowRes.png)
Custom Transformation Template Available for Selection in the Initiative Fact Sheet
